🔖 [Table of Contents](../README.md)

# Technical Documentation

- [Tasks](tasks/README.md)
  - [AnyTask](tasks/any-task.md)
  - [BaseTask](tasks/base-task.md)
  - [Task](tasks/task.md)
  - [`@python_task` Decorator](tasks/python-task.md)
  - [CmdTask](tasks/cmd-task.md)
  - [DockerComposeTask](tasks/docker-compose-task.md)
  - [ResourceMaker](tasks/resource-maker.md)
  - [notifier](tasks/notifier.md)
  - [FlowTask](tasks/flow-task.md)
  - [BaseRemoteCmdTask](tasks/base-remote-cmd-task.md)
  - [RemoteCmdTask](tasks/remote-cmd-task.md)
  - [RsyncTask](tasks/rsync-task.md)
  - [Checker](tasks/checker.md)
  - [PathChecker](tasks/path-checker.md)
  - [PortChecker](tasks/port-checker.md)
  - [HTTPChecker](tasks/http-checker.md)
  - [PathWatcher](tasks/path-watcher.md)
  - [TimeWatcher](tasks/time-watcher.md)
- [Task Group](task-group.md)
- [Task Inputs](task-inputs/README.md)
  - [Input](task-inputs/input.md)
  - [BoolInput](task-inputs/bool-input.md)
  - [ChoiceInput](task-inputs/choice-input.md)
  - [FloatInput](task-inputs/float-input.md)
  - [IntInput](task-inputs/int-input.md)
  - [PasswordInput](task-inputs/password-input.md)
  - [StrInput](task-inputs/str-input.md)
- [Task Env](task-envs/README.md)
  - [Env](task-envs/env.md)
  - [EnvFile](task-envs/env-file.md)

🔖 [Table of Contents](../README.md)
